@@ -21,6 +21,13 @@ struct vzctl_snapshot_tree {
 
 struct vzctl_snapshot_param;
 
+#define SNAPSHOT_XML	"Snapshots.xml"
+#define GET_SNAPSHOT_XML(buf, ve_private) \
+	snprintf(buf, sizeof(buf), "%s/" SNAPSHOT_XML, ve_private);
+
+#define GET_SNAPSHOT_XML_TMP(buf, ve_private) \
+	snprintf(buf, sizeof(buf), "%s/" SNAPSHOT_XML ".tmp", ve_private);
+
 /* src/lib/snapshot.c */
 void vzctl_free_snapshot_tree(struct vzctl_snapshot_tree *tree);
 struct vzctl_snapshot_tree *vzctl_alloc_snapshot_tree(void);
@@ -38,6 +45,7 @@ int vzctl_read_snapshot_tree(const char *fname, struct vzctl_snapshot_tree *tree
 int vzctl_store_snapshot_tree(const char *fname, struct vzctl_snapshot_tree *tree);
 
 /* src/snapshot.c */
+int is_snapshot_supported(const char *ve_private);
 int vzctl_env_create_snapshot(vps_handler *h, envid_t veid, const fs_param *fs,
 		const struct vzctl_snapshot_param *param);
 
@@ -47,6 +55,8 @@ int vzctl_env_switch_snapshot(vps_handler *h, envid_t veid, vps_param *g_p,
 int vzctl_env_delete_snapshot(vps_handler *h, envid_t veid, const fs_param *fs,
 		const char *guid);
 
-int vzctl_env_list_snapshot_tree(const char *ve_private);
+/* src/snapshot-list.c */
+int vzctl_env_snapshot_list(int argc, char **argv, int envid,
+		const char *ve_private);
 #endif /* __SNAPSHOT_H__ */
 #endif /* HAVE_PLOOP */
