@@ -31,6 +31,7 @@
 
 char *parse_line(char *str, char *ltoken, int lsz, char **errstr);
 int stat_file(const char *file);
+int dir_empty(const char *dir);
 int make_dir(const char *path, int full);
 int make_dir_mode(const char *path, int full, int mode);
 char *get_fs_root(const char *dir);
@@ -68,6 +69,8 @@ int ve_in_list(envid_t *list, int size, envid_t ve);
 const char* ubcstr(unsigned long bar, unsigned long lim);
 int is_vswap_mode(void);
 
+int vzctl_get_normalized_guid(const char *str, char *buf, int len);
+
 #define logger_enomem(log_level, err, size, file, line)			\
 	logger(log_level, err, "%s:%i: Can't allocate %lu bytes",	\
 		file, line, (unsigned long)size)
