@@ -38,9 +38,10 @@
 #include "destroy.h"
 
 #define DEFAULT_FSTYPE		"ext4"
+#define SNAPSHOT_MOUNT_ID	"snap"
 
 #ifdef HAVE_PLOOP
-struct ploop_functions ploop = { NULL };
+struct ploop_functions ploop;
 #endif
 
 /* We want get_ploop_type() to work even if vzctl is compiled
@@ -445,6 +446,14 @@ int vzctl_merge_snapshot(const char *ve_private, const char *guid)
 	return ret;
 }
 
+
+const char *generate_snapshot_component_name(unsigned int envid,
+		const char *data, char *buf, int len)
+{
+	snprintf(buf, len, "%d-%s-%s", envid, SNAPSHOT_MOUNT_ID, data);
+	return buf;
+}
+
 /* Convert a CT to ploop layout
  * 1) mount CT
  * 2) create & mount image
