@@ -26,7 +26,10 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <sys/file.h>
+#ifdef HAVE_PLOOP
 #include <ploop/libploop.h>
+#include "image.h"
+#endif
 
 #include "types.h"
 #include "logger.h"
@@ -41,9 +44,14 @@ typedef struct {
 	int verbose;		/**< Console verbosity. */
 	char prog[32];		/**< program name. */
 	envid_t veid;		/**< Container ID (CTID). */
+	char *file;		/**< log file name */
 } log_param;
 
-log_param g_log = {NULL, 0, 1, 0, 0, "", 0};
+log_param g_log = {NULL, 0, 1, 0, 0, "", 0, NULL};
+
+#ifdef HAVE_PLOOP
+static int ploop_log = 0;
+#endif
 
 static inline void get_date(char *buf, int len)
 {
@@ -101,12 +109,20 @@ int set_log_file(char *file)
 		fclose(g_log.fp);
 		g_log.fp = NULL;
 	}
+	if (g_log.file) {
+		free(g_log.file);
+		g_log.file = NULL;
+	}
 	if (file != NULL) {
 		if ((fp = fopen(file, "a")) == NULL)
 			return -1;
 		g_log.fp = fp;
+		g_log.file = strdup(file);
 	}
-	ploop_set_log_file(file);
+#ifdef HAVE_PLOOP
+	if (ploop_log)
+		ploop.set_log_file(file);
+#endif
 	return 0;
 }
 
@@ -114,19 +130,26 @@ void free_log()
 {
 	if (g_log.fp  != NULL)
 		fclose(g_log.fp);
+	free(g_log.file);
 	memset(&g_log, 0, sizeof(g_log));
 }
 
 void set_log_level(int level)
 {
 	g_log.level = level;
-	ploop_set_log_level(level);
+#ifdef HAVE_PLOOP
+	if (ploop_log)
+		ploop.set_log_level(level);
+#endif
 }
 
 void set_log_verbose(int level)
 {
 	g_log.verbose = level;
-	ploop_set_verbose_level(level);
+#ifdef HAVE_PLOOP
+	if (ploop_log)
+		ploop.set_verbose_level(level);
+#endif
 }
 
 void set_log_ctid(envid_t id) {
@@ -135,7 +158,10 @@ void set_log_ctid(envid_t id) {
 
 void set_log_quiet(int quiet) {
 	g_log.quiet = quiet;
-	ploop_set_verbose_level(PLOOP_LOG_NOCONSOLE);
+#ifdef HAVE_PLOOP
+	if (ploop_log)
+		ploop.set_verbose_level(PLOOP_LOG_NOCONSOLE);
+#endif
 }
 
 int init_log(char *file, envid_t veid, int enable, int level, int quiet,
@@ -156,10 +182,28 @@ int init_log(char *file, envid_t veid, int enable, int level, int quiet,
 	else
 		g_log.prog[0] = 0;
 
-	ploop_set_log_file(file);
-	ploop_set_log_level(level);
-	if (!quiet)
-		ploop_set_verbose_level(level);
+#ifdef HAVE_PLOOP
+	if (ploop_log) {
+		ploop.set_log_file(file);
+		ploop.set_log_level(level);
+		if (!quiet)
+			ploop.set_verbose_level(level);
+	}
+#endif
 
 	return 0;
 }
+
+#ifdef HAVE_PLOOP
+void vzctl_init_ploop_log(void)
+{
+	ploop.set_log_file(g_log.file);
+	ploop.set_log_level(g_log.level);
+	if (!g_log.quiet)
+		ploop.set_verbose_level(g_log.level);
+	else
+		ploop.set_verbose_level(PLOOP_LOG_NOCONSOLE);
+
+	ploop_log = 1;
+}
+#endif
