@@ -28,14 +28,6 @@
 #define VZCTL_VE_DUMP_DIR	"/dump"
 #define VZCTL_VE_CONF		"ve.conf"
 
-#define SNAPSHOT_XML	"Snapshots.xml"
-#define GET_SNAPSHOT_XML(buf, ve_private) \
-	snprintf(buf, sizeof(buf), "%s/" SNAPSHOT_XML, ve_private);
-
-#define GET_SNAPSHOT_XML_TMP(buf, ve_private) \
-	snprintf(buf, sizeof(buf), "%s/" SNAPSHOT_XML ".tmp", ve_private);
-
-
 static void vzctl_get_snapshot_dumpfile(const char *private, const char *guid,
 		char *buf, int len)
 {
@@ -49,7 +41,7 @@ static void vzctl_get_snapshot_ve_conf(const char *private, const char *guid,
 			private, guid);
 }
 
-static int is_snapshot_supported(const char *ve_private)
+int is_snapshot_supported(const char *ve_private)
 {
 	if (! ve_private_is_ploop(ve_private)) {
 		logger(-1, 0, "Snapshot feature is only available "
@@ -400,47 +392,3 @@ err:
 	vzctl_free_snapshot_tree(tree);
 	return VZCTL_E_DELETE_SNAPSHOT;
 }
-
-static void print_snapshot_data(struct vzctl_snapshot_data *data)
-{
-	printf("%38s %c%38s %19s %s\n",
-			data->parent_guid,
-			data->current ? '*' : ' ',
-			data->guid,
-			data->date,
-			data->name);
-}
-
-int vzctl_env_list_snapshot_tree(const char *ve_private)
-{
-	char fname[PATH_MAX];
-	struct vzctl_snapshot_tree *tree = NULL;
-	int i, ret = 0;
-
-	if (ve_private == NULL)
-		return vzctl_err(VZ_VE_PRIVATE_NOTSET, 0, "VE_PRIVATE is not specified");
-
-	GET_SNAPSHOT_XML(fname, ve_private)
-	if (stat_file(fname) != 1)
-		return 0;
-
-	tree = vzctl_alloc_snapshot_tree();
-	if (tree == NULL)
-		return VZ_RESOURCE_ERROR;
-
-	ret = vzctl_read_snapshot_tree(fname, tree);
-	if (ret) {
-		logger(-1, 0, "Failed to read %s", fname);
-		goto err;
-	}
-
-	printf("%-38s  %-38s %-19s %-s\n",
-		"PARENT_UUID", "UUID", "DATE", "NAME");
-	for (i = 0; i < tree->nsnapshots; i++)
-		print_snapshot_data(tree->snapshots[i]);
-
-err:
-	vzctl_free_snapshot_tree(tree);
-	return ret;
-
-}
