@@ -1317,6 +1317,8 @@ int parse_action_opt(envid_t veid, act_t action, int argc, char *argv[],
 	case ACTION_SNAPSHOT_SWITCH:
 		ret = parse_snapshot_delete_opt(veid, argc, argv, param);
 		break;
+	case ACTION_SNAPSHOT_LIST:
+		break;
 #endif
 	default :
 		if ((argc - 1) > 0) {
@@ -1444,15 +1446,15 @@ int run_action(envid_t veid, act_t action, vps_param *g_p, vps_param *vps_p,
 		ret = show_status(h, veid, g_p);
 		break;
 	case ACTION_ENTER:
-		ret = enter(h, veid, g_p->res.fs.root, argc, argv);
+		ret = enter(h, veid, g_p->res.fs.root, argc-1, argv+1);
 		break;
 	case ACTION_CONSOLE:
-		ret = console_attach(h, veid, argc, argv);
+		ret = console_attach(h, veid, argc-1, argv+1);
 		break;
 	case ACTION_EXEC:
 	case ACTION_EXEC2:
 	case ACTION_EXEC3:
-		ret = exec(h, action, veid, g_p->res.fs.root, argc, argv);
+		ret = exec(h, action, veid, g_p->res.fs.root, argc-1, argv+1);
 		if (ret && action == ACTION_EXEC)
 			ret = VZ_COMMAND_EXECUTION_ERROR;
 		break;
@@ -1463,7 +1465,7 @@ int run_action(envid_t veid, act_t action, vps_param *g_p, vps_param *vps_p,
 		ret = restore(h, veid, g_p, cmd_p);
 		break;
 	case ACTION_RUNSCRIPT:
-		ret = vps_run_script(h, veid, argv[0], g_p);
+		ret = vps_run_script(h, veid, argv[1], g_p);
 		break;
 
 #define CHECK_DQ(r)								\
@@ -1507,7 +1509,8 @@ int run_action(envid_t veid, act_t action, vps_param *g_p, vps_param *vps_p,
 				cmd_p->snap.guid);
 		break;
 	case ACTION_SNAPSHOT_LIST:
-		ret = vzctl_env_list_snapshot_tree(g_p->res.fs.private);
+		ret = vzctl_env_snapshot_list(argc, argv, veid,
+				g_p->res.fs.private);
 		break;
 #endif
 	case ACTION_CUSTOM:
